@@ -4,7 +4,7 @@
  *  Manage a server shell process
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -114,7 +114,7 @@ ag_scm_shell(SCM cmd)
 SCM
 ag_scm_shellf(SCM fmt, SCM alist)
 {
-    int   len = scm_ilength(alist);
+    int   len = (int)scm_ilength(alist);
     char* pz;
 
 #ifdef DEBUG_ENABLED
@@ -146,9 +146,9 @@ HIDE_FN(char * shell_cmd(char const* pzCmd)) {
 /*
  *  Dual pipe opening of a child process
  */
-static fp_pair_t      serv_pair     = { NULL, NULL };
+static fp_pair_t    serv_pair     = { NULL, NULL };
 static pid_t        serv_id       = NULLPROCESS;
-static bool      was_close_err = false;
+static bool         was_close_err = false;
 static int          log_ct        = 0;
 static char const * last_cmd      = NULL;
 
@@ -535,7 +535,7 @@ server_fp_open(fp_pair_t * fp_pair, char const ** ppArgs)
 static inline void
 realloc_text(char ** p_txt, size_t * p_sz, size_t need_len)
 {
-    *p_sz  = (*p_sz + need_len + 0xFFF) & ~0xFFF;
+    *p_sz  = (*p_sz + need_len + 0xFFF) & (size_t)~0xFFF;
     *p_txt = AGREALOC((void*)*p_txt, *p_sz, "expand text");
 }
 
@@ -620,7 +620,7 @@ load_data(void)
     while (  (scan > text)
           && IS_WHITESPACE_CHAR(scan[-1]))
         scan--;
-    text_sz = (scan - text) + 1;
+    text_sz = (size_t)(scan - text) + 1;
     *scan  = NUL;
 
     if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL)
