@@ -5,7 +5,7 @@
  *  Global header file for AutoGen
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -26,9 +26,29 @@
 #include "compat/unlocked-io.h"
 
 #include REGEX_HEADER
+#if !defined(__GNUC__)
+#define GCC_VERSION 0
+#elif ! defined(GCC_VERSION)
+#define GCC_VERSION (__GNUC__ * 10000 \
+                    + __GNUC_MINOR__ * 100 \
+                    + __GNUC_PATCHLEVEL__)
+#endif
+
+#if GCC_VERSION > 40400
+#pragma  GCC diagnostic push
+#pragma  GCC diagnostic ignored "-Wextra"
+#pragma  GCC diagnostic ignored "-Wconversion"
+#pragma  GCC diagnostic ignored "-Wsign-conversion"
+#pragma  GCC diagnostic ignored "-Wstrict-overflow"
+#endif
+
 #include <libguile/scmconfig.h>
 #include <libguile.h>
 
+#if GCC_VERSION > 40400
+#pragma  GCC diagnostic pop
+#endif
+
 #include "ag-text.h"
 #include "opts.h"
 #include "expr.h"
@@ -523,20 +543,27 @@ MODE v2c_t p2p VALUE( { NULL } );
 
 #include "proto.h"
 
-static inline SCM ag_eval(char const * pzStr)
+/**
+ * Evaluate a scheme expression, setting the file and line number from
+ * the file and line of the currently active macro.
+ *
+ * @param[in] str  the scheme expression
+ * @returns the SCM result.  That may be SCM_UNDEFINED.
+ */
+static inline SCM ag_eval(char const * str)
 {
     SCM res;
-    char const * pzSaveScheme = last_scm_cmd; /* Watch for nested calls */
-    last_scm_cmd = pzStr;
+    char const * sv = last_scm_cmd; /* Watch for nested calls */
+    last_scm_cmd = str;
 
     res = ag_scm_c_eval_string_from_file_line(
-        pzStr, current_tpl->td_file, cur_macro->md_line);
+        str, current_tpl->td_file, cur_macro->md_line);
 
-    last_scm_cmd = pzSaveScheme;
+    last_scm_cmd = sv;
     return res;
 }
 
-/*
+/**
  *  Extracted from guile-iface stuff.  Seems to be stable since for at least
  *  1.6.0 through 2.0.0.  1.4.x is thoroughly dead now (May, 2011).
  */
@@ -551,11 +578,12 @@ static inline SCM ag_eval(char const * pzStr)
 
 #define AG_SCM_CHAR_P(_c)            SCM_CHARP(_c)
 
-/*
+/**
  * Hide dummy functions from complexity measurement tools
  */
 #define HIDE_FN(_t)  _t
 
+#define LOCAL static
 #endif /* AUTOGEN_BUILD */
 /*
  * Local Variables:
