@@ -5,7 +5,7 @@
  *  Parse and process the template data descriptions
  *
  * This file is part of AutoGen.
- * AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
+ * AutoGen Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -394,7 +394,7 @@ open_output(out_spec_t * spec)
         if (end != NULL) {
             size_t len = (unsigned)(end - pst);
             if (len >= sizeof(z))
-                AG_ABEND("--base-name name is too long");
+                AG_ABEND(BASE_NAME_TOO_LONG);
 
             memcpy(z, pst, len);
             z[ end - pst ] = NUL;
