@@ -1,11 +1,11 @@
 /**
  * \file gdinit.c
  *
- *  getdefs Copyright (c) 1999-2012 by Bruce Korb - all rights reserved
+ *  getdefs Copyright (C) 1999-2013 by Bruce Korb - all rights reserved
  *
  *  Author:            Bruce Korb <bkorb@gnu.org>
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2012 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
  *
  *  AutoGen is free software: you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -93,7 +93,7 @@ compressOptionText(char* pzS, char* pzE)
     } compressDone:;
 
     {
-        size_t len = (pzD - pzR);
+        size_t len = (size_t)(pzD - pzR);
         pzD = malloc(len + 1);
         if (pzD == NULL)
             die("cannot dup %d byte string\n", (int)(pzD - pzR));
@@ -441,8 +441,8 @@ validateOptions(void)
             indexAlloc = 0x4000;
             pzEndIndex += sprintf(pzEndIndex, "%s", zIndexPreamble);
         } else {
-            pzEndIndex  = pzIndexEOF = pzIndexText + strlen(pzIndexText);
-            indexAlloc = (pzEndIndex - pzIndexText) + 1;
+            pzEndIndex = pzIndexEOF = pzIndexText + strlen(pzIndexText);
+            indexAlloc = (size_t)(pzEndIndex - pzIndexText) + 1;
         }
 
         /*
